@@ -28,19 +28,19 @@
 #include <QInputDialog>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
-#include <kactioncollection.h>
-#include <kcodecs.h>
-#include <kmessagebox.h>
+#include <KActionCollection>
+#include <KCodecs>
+#include <KMessageBox>
 #include <QMenu>
-#include <ksqueezedtextlabel.h>
-#include <kstandardaction.h>
+#include <KSqueezedTextLabel>
+#include <KStandardAction>
 #include <KConfigGroup>
 
 #include <QTemporaryFile>
-#include <kxmlguifactory.h>
+#include <KXMLGUIFactory>
 #include <KSharedConfig>
 
-#include <ktoolbar.h>
+#include <KToolBar>
 #include <KLocalizedString>
 #include <QIcon>
 #include <KTreeWidgetSearchLine>
@@ -137,6 +137,8 @@ KWalletEditor::KWalletEditor(QWidget *parent, const QString &name)
     connect(_showContents, &QToolButton::clicked, this, &KWalletEditor::showPasswordContents);
     connect(_hideContents, &QToolButton::clicked, this, &KWalletEditor::hidePasswordContents);
 
+    _passwordValue->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
+
     _binaryViewShow->setChecked(_alwaysShowContents);
 //    createActions();
     // TODO: remove kwalleteditor.rc file
